@@ -79,6 +79,10 @@ $commands = [
   "diff -u enable_slots_nodisablexml1_sup.py enable_slots_nodisablexml2_sup.py",
   "diff -u enable_slots1_sub.py enable_slots2_sub.py",
   "diff -u enable_slots1_sup.py enable_slots2_sup.py",
+  "diff -u preserve_cdata_tags1_sub.py preserve_cdata_tags2_sub.py",
+  "diff -u preserve_cdata_tags1_sup.py preserve_cdata_tags2_sup.py",
+  "diff -u decimal_format1_sub.py decimal_format2_sub.py",
+  "diff -u decimal_format1_sup.py decimal_format2_sup.py",
 ]
 
 def check
