@@ -394,6 +394,8 @@ class GenTest(unittest.TestCase):
         )
         t_ = 'ipo'
         cmd = cmdTempl % (t_, t_, t_, t_, )
+        # dbg
+        print('-' * 50, '\ncmd:', cmd, '\n', '-' * 50)
         self.executeClean(cmd)
         self.compareFiles(
             '{}1_sup.py'.format(t_),
@@ -1201,7 +1203,7 @@ def strip_build_comments(lines):
     assert isinstance(lines, list), type(lines)
 
     # Rstrip all the whitespace characters
-    lines = [l.rstrip() + '\n' for l in lines]
+    lines = [line.rstrip() + '\n' for line in lines]
 
     if '#!/usr/bin/env python' in lines[0]:
 
