@@ -959,7 +959,7 @@ def _cast(typ, value):
 class PersonType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('personId', 'xs:integer', 0, 0, {'maxOccurs': '1', 'minOccurs': '1', 'name': 'personId', 'ref': 'personId', 'type': 'personId'}, None),
+        MemberSpec_('personId', 'PersonIdType1', 0, 0, {'maxOccurs': '1', 'minOccurs': '1', 'name': 'personId', 'ref': 'personId', 'type': 'personId'}, None),
         MemberSpec_('fname', 'xs:string', 0, 0, {'name': 'fname', 'type': 'xs:string'}, None),
         MemberSpec_('lname', 'xs:string', 0, 0, {'name': 'lname', 'type': 'xs:string'}, None),
     ]
@@ -1045,8 +1045,7 @@ class PersonType(GeneratedsSuper):
             eol_ = ''
         if self.personId is not None:
             namespaceprefix_ = self.personId_nsprefix_ + ':' if (UseCapturedNS_ and self.personId_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%spersonId>%s</%spersonId>%s' % (namespaceprefix_ , self.gds_format_integer(self.personId, input_name='personId'), namespaceprefix_ , eol_))
+            self.personId.export(outfile, level, namespaceprefix_, namespacedef_='', name_='personId', pretty_print=pretty_print)
         if self.fname is not None:
             namespaceprefix_ = self.fname_nsprefix_ + ':' if (UseCapturedNS_ and self.fname_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
@@ -1069,12 +1068,11 @@ class PersonType(GeneratedsSuper):
     def buildAttributes(self, node, attrs, already_processed):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'personId' and child_.text:
-            sval_ = child_.text
-            ival_ = self.gds_parse_integer(sval_, node, 'personId')
-            ival_ = self.gds_validate_integer(ival_, node, 'personId')
-            self.personId = ival_
-            self.personId_nsprefix_ = child_.prefix
+        if nodeName_ == 'personId':
+            obj_ = PersonIdType1.factory(parent_object_=self)
+            obj_.build(child_, gds_collector_=gds_collector_)
+            self.personId = obj_
+            obj_.original_tagname_ = 'personId'
         elif nodeName_ == 'fname':
             value_ = child_.text
             value_ = self.gds_parse_string(value_, node, 'fname')
@@ -1090,8 +1088,93 @@ class PersonType(GeneratedsSuper):
 # end class PersonType
 
 
+class PersonIdType1(GeneratedsSuper):
+    __hash__ = GeneratedsSuper.__hash__
+    member_data_items_ = [
+        MemberSpec_('valueOf_', ['PersonIdType', 'eitc:IdType'], 0),
+    ]
+    subclass = None
+    superclass = None
+    def __init__(self, valueOf_=None, gds_collector_=None, **kwargs_):
+        self.gds_collector_ = gds_collector_
+        self.gds_elementtree_node_ = None
+        self.original_tagname_ = None
+        self.parent_object_ = kwargs_.get('parent_object_')
+        self.ns_prefix_ = None
+        self.valueOf_ = valueOf_
+    def factory(*args_, **kwargs_):
+        if CurrentSubclassModule_ is not None:
+            subclass = getSubclassFromModule_(
+                CurrentSubclassModule_, PersonIdType1)
+            if subclass is not None:
+                return subclass(*args_, **kwargs_)
+        if PersonIdType1.subclass:
+            return PersonIdType1.subclass(*args_, **kwargs_)
+        else:
+            return PersonIdType1(*args_, **kwargs_)
+    factory = staticmethod(factory)
+    def get_ns_prefix_(self):
+        return self.ns_prefix_
+    def set_ns_prefix_(self, ns_prefix):
+        self.ns_prefix_ = ns_prefix
+    def get_valueOf_(self): return self.valueOf_
+    def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
+    def hasContent_(self):
+        if (
+            (1 if type(self.valueOf_) in [int,float] else self.valueOf_)
+        ):
+            return True
+        else:
+            return False
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType1', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('PersonIdType1')
+        if imported_ns_def_ is not None:
+            namespacedef_ = imported_ns_def_
+        if pretty_print:
+            eol_ = '\n'
+        else:
+            eol_ = ''
+        if self.original_tagname_ is not None and name_ == 'PersonIdType1':
+            name_ = self.original_tagname_
+        if UseCapturedNS_ and self.ns_prefix_:
+            namespaceprefix_ = self.ns_prefix_ + ':'
+        showIndent(outfile, level, pretty_print)
+        outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
+        already_processed = set()
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PersonIdType1')
+        if self.hasContent_():
+            outfile.write('>')
+            outfile.write(self.convert_unicode(self.valueOf_))
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PersonIdType1', pretty_print=pretty_print)
+            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
+        else:
+            outfile.write('/>%s' % (eol_, ))
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='PersonIdType1'):
+        pass
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType1', fromsubclass_=False, pretty_print=True):
+        pass
+    def build(self, node, gds_collector_=None):
+        self.gds_collector_ = gds_collector_
+        if SaveElementTreeNode:
+            self.gds_elementtree_node_ = node
+        already_processed = set()
+        self.ns_prefix_ = node.prefix
+        self.buildAttributes(node, node.attrib, already_processed)
+        self.valueOf_ = get_all_text_(node)
+        for child in node:
+            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
+            self.buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
+        return self
+    def buildAttributes(self, node, attrs, already_processed):
+        pass
+    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
+        pass
+# end class PersonIdType1
+
+
 GDSClassesMapping = {
     'person': PersonType,
+    'personId': PersonIdType1,
 }
 
 
@@ -1287,5 +1370,6 @@ RenameMappings_ = {
 NamespaceToDefMappings_ = {}
 
 __all__ = [
+    "PersonIdType1",
     "PersonType"
 ]
